==> openjdk-13_13.0.7+5.orig.tar.xz: openjdk-13-13.0.7+5/test/langtools/jdk/javadoc/doclet/testLinkOption/TestBadLinkOption.java <==
/*
 * Copyright (c) 2003, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 4625883 8180019
 * @summary Make sure that bad -link arguments trigger errors.
 * @author jamieh
 * @library ../../lib
 * @modules jdk.javadoc/jdk.javadoc.internal.tool
 * @build javadoc.tester.*
 * @run main TestBadLinkOption
 */

import javadoc.tester.JavadocTester;

public class TestBadLinkOption extends JavadocTester {

    public static void main(String... args) throws Exception {
        TestBadLinkOption tester = new TestBadLinkOption();
        tester.runTests();
    }

    @Test
    public void test() {
        String out = "out";
        javadoc("-d", out,
                "-sourcepath", testSrc,
                "-link", "a-non-existent-link",
                "pkg");
        checkExit(Exit.ERROR);

        checkOutput(Output.OUT, true,
                "Error reading file:");
    }
}

==> openjdk-17_17.0.17+10.orig.tar.xz: openjdk-17-17.0.17+10/test/langtools/jdk/javadoc/doclet/testLinkOption/TestBadLinkOption.java <==
/*
 * Copyright (c) 2003, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 4625883 8180019
 * @summary Make sure that bad -link arguments trigger errors.
 * @library ../../lib
 * @modules jdk.javadoc/jdk.javadoc.internal.tool
 * @build javadoc.tester.*
 * @run main TestBadLinkOption
 */

import javadoc.tester.JavadocTester;

public class TestBadLinkOption extends JavadocTester {

    public static void main(String... args) throws Exception {
        var tester = new TestBadLinkOption();
        tester.runTests();
    }

    @Test
    public void test() {
        String out = "out";
        javadoc("-d", out,
                "-sourcepath", testSrc,
                "-link", "a-non-existent-link",
                "pkg");
        checkExit(Exit.ERROR);

        checkOutput(Output.OUT, true,
                "Error reading file:");
    }
}
